@@ -13,7 +13,6 @@ import psutil
 
 import psi4_step
 import seamm
-from seamm import data  # noqa: F401
 from seamm_util import ureg, Q_  # noqa: F401
 import seamm_util.printing as printing
 from seamm_util.printing import FormattedText as __
@@ -198,6 +197,28 @@ class Psi4(seamm.Node):
             help='The amount of memory to use for Psi4'
         )
 
+        self.parser.add_argument(
+            '--psi4-memory-factor',
+            default='90%',
+            help=(
+                'The amount of possible memory to use, typically about 90% to '
+                'allow for Psi4 not keeping track of all the memory used.'
+            )
+        )
+
+        # General options from seamm.ini on max cores and memory
+        self.parser.add_argument(
+            '--max-cores',
+            default='unlimited',
+            help='The maximum number of cores/threads to use in any step.'
+        )
+
+        self.parser.add_argument(
+            '--max-memory',
+            default='available',
+            help='The maximum amount of memory to use in any step.'
+        )
+
         self.options, self.unknown = self.parser.parse_known_args()
 
         # Set the logging level for this module if requested
@@ -276,7 +297,9 @@ class Psi4(seamm.Node):
         printer.important(self.header)
         printer.important('')
 
-        if data.structure is None:
+        system = self.get_variable('_system')
+        n_atoms = system.n_atoms()
+        if n_atoms == 0:
             logger.error('Psi4 run(): there is no structure!')
             raise RuntimeError('Psi4 run(): there is no structure!')
 
@@ -297,13 +320,23 @@ class Psi4(seamm.Node):
         if n_threads < 1:
             n_threads = 1
         if o.psi4_max_threads != 'default':
-            if n_threads > o.psi4_max_threads:
-                n_threads = o.psi4_max_threads
+            if n_threads > int(o.psi4_max_threads):
+                n_threads = int(o.psi4_max_threads)
+        if o.max_cores != "unlimited":
+            if n_threads > int(o.max_cores):
+                n_threads = int(o.max_cores)
         logger.info(f'Psi4 will use {n_threads} threads.')
 
         # How much memory to use
+        if '%' in o.psi4_memory_factor:
+            factor = float(o.psi4_memory_factor.rstrip('%')) / 100.0
+        else:
+            factor = float(o.psi4_memory_factor)
         svmem = psutil.virtual_memory()
-        available = svmem.available * 0.9  # Safety factor....
+        if o.max_memory == 'all':
+            available = svmem.total * factor
+        else:
+            available = svmem.available * factor
         if o.psi4_memory == 'default':
             memory = available * (n_threads / n_cores)
         else:
@@ -312,6 +345,9 @@ class Psi4(seamm.Node):
             max_memory = dehumanize(o.psi4_max_memory)
             if memory > max_memory:
                 memory = max_memory
+        if o.max_memory != 'all' and o.max_memory != 'available':
+            if memory > dehumanize(o.max_memory):
+                memory = dehumanize(o.max_memory)
         # Psi applies a minimum of 250 MiB
         min_memory = dehumanize('250 MiB')
         if min_memory > memory:
@@ -448,13 +484,18 @@ class Psi4(seamm.Node):
             with structure_file.open(mode='r') as fd:
                 structure = json.load(fd)
         if 'geom' in structure:
-            system = seamm.data.structure
-            atoms = system['atoms']
-            xyz = []
+            system = self.get_variable('_system')
+            xs = []
+            ys = []
+            zs = []
             it = iter(structure['geom'])
             for x in it:
-                xyz.append([x, next(it), next(it)])
-            atoms['coordinates'] = xyz
+                xs.append(x)
+                ys.append(next(it))
+                zs.append(next(it))
+            system.atoms['x'][0:] = xs
+            system.atoms['y'][0:] = ys
+            system.atoms['z'][0:] = zs
             printer.important(
                 self.indent +
                 '    Updated the system with the structure from Psi4',
@@ -464,7 +505,7 @@ class Psi4(seamm.Node):
     def _convert_structure(self, name=None):
         """Convert the structure to the input for Psi4."""
 
-        system = seamm.data.structure
+        system = self.get_variable('_system')
 
         structure = []
         if name is None:
@@ -476,7 +517,7 @@ class Psi4(seamm.Node):
         if 'extras' in system:
             extras = system['extras']
 
-            if 'open' in extras:
+            if 'open' in extras and extras['open'] is not None:
                 openshell = extras['open']
                 if (
                     (
@@ -494,19 +535,19 @@ class Psi4(seamm.Node):
                     nopen = openshell
                     norbitals = nopen
 
-                if 'net_charge' in extras:
+                if 'net_charge' in extras and extras['net_charge'] is not None:
                     structure.append(f"    {extras['net_charge']}   {nopen}")
                 else:
                     structure.append(f'    0   {nopen}')
             else:
-                if 'net_charge' in extras:
-                    structure.append(f"    {extras['net_charge']}   0")
+                if 'net_charge' in extras and extras['net_charge'] is not None:
+                    structure.append(f"    {extras['net_charge']}   1")
 
-        elements = system['atoms']['elements']
-        coordinates = system['atoms']['coordinates']
+        elements = system.atoms.symbols()
+        coordinates = system.atoms.coordinates()
 
-        if 'freeze' in system['atoms']:
-            freeze = system['atoms']['freeze']
+        if 'freeze' in system.atoms:
+            freeze = system.atoms['freeze']
         else:
             freeze = [''] * len(elements)
 
